function [J,ind]=ssnr2(c,nu)
% [J,ind] = ssnr2(c,nu)
%
%     c = FIR filter
%     nu = window length - 1
%     ind = index of first tap in window (start at 1, not 0)
%
%               (energy in window)
%     J = max -----------------------
%             (energy outside window)
%
%     (optimized over window location)
%      
%     Written by Rick Martin on 02/07/2002
%     Last updated on 05/15/2002
%     Cornell University Blind Equalization Research Group
%
%     Copyright 2002 Cornell University, All Rights Reserved
%
%     SOFTWARE shall mean "ssnr2.m", Cornell Research Foundation 
%     ("CRF") Docket D-3006.  SOFTWARE is made available to allow
%     non-commercial and research use of SOFTWARE.  Cornell
%     University specifically reserves all commercial rights to
%     SOFTWARE and these rights may be licensed by CRF on behalf   
%     of Cornell University to third parties.
%
%     CRF provides SOFTWARE on an ``as is'' basis.  CRF does not
%     warrant, guarantee, or make any representations regarding 
%     the use or results of SOFTWARE with respect to its
%     correctness, accuracy, reliability or performance.  The
%     entire risk of the use and performance of SOFTWARE is  
%     assumed by EVALUATOR.  ALL WARRANTIES INCLUDING, WITHOUT
%     LIMITATION, ANY WARRANTY OF FITNESS  FOR A PARTICULAR   
%     PURPOSE OR MERCHANTABILITY ARE HEREBY EXCLUDED.

L = length(c);
E = sum(abs(c).^2);

Js = zeros(1,L-nu);
for win=1:L-nu
   E_in    = sum(abs(c(win:win+nu)).^2);
   E_out   = E - E_in;
   Js(win) = E_in/E_out;
end;

[J,ind] = max(Js);
